scan_last_checkpoint

Function scan_last_checkpoint 

pub fn scan_last_checkpoint(
    path: impl AsRef<Path>,
    encoding: Encoding,
) -> Result<Option<(Checkpoint, Uuid)>, JournalError>
Scan a journal file forward and return the last [Checkpoint] event found.

Returns None when the journal contains no checkpoint events. Does NOT reduce events — this is a lightweight linear scan.