CheckpointData

Struct CheckpointData 

pub struct CheckpointData {
    pub run_id: Uuid,
    pub up_to_seq: u64,
    pub state_hash: String,
    pub state: PortfolioState,
}
Pre-loaded checkpoint state used to skip early events during replay.

Fields

run_id: Uuid

Run identity that this checkpoint belongs to.

up_to_seq: u64

The up_to_seq from the Checkpoint event.

state_hash: String

The expected checkpoint-state hash at the checkpoint boundary, including retirement markers restored from the checkpoint payload.

state: PortfolioState

The deserialized portfolio state at the checkpoint.